@@ -15,7 +15,7 @@ use Rose::DB::Object::Constants qw(:all);
 use Rose::DB::Constants qw(IN_TRANSACTION);
 use Rose::DB::Object::Util qw(row_id);
 
-our $VERSION = '0.080';
+our $VERSION = '0.081';
 
 our $Debug = 0;
 
@@ -1093,10 +1093,14 @@ Rose::DB::Object - Extensible, high performance RDBMS-OO mapper.
 
 =head1 SYNOPSIS
 
+  ## For an informal overview of Rose::DB::Object, please
+  ## see the Rose::DB::Object::Tutorial documentation.  The
+  ## reference documentation follows.
+
   ## First, set up your Rose::DB data sources, otherwise you
   ## won't be able to connect to the database at all.  See 
   ## the Rose::DB documentation for more information.  For
-  ## a quick start, run: perldoc Rose::DB::Tutorial
+  ## a quick start, see the Rose::DB::Tutorial documentation.
 
   ##
   ## Create classes - two possible approaches:
@@ -1281,6 +1285,8 @@ L<Rose::DB::Object> is a base class for objects that encapsulate a single row in
 
 L<Rose::DB::Object> inherits from, and follows the conventions of, L<Rose::Object>.  See the L<Rose::Object> documentation for more information.
 
+For an informal overview of this module distribution, consult the L<Rose::DB::Object::Tutorial>.
+
 =head2 Restrictions
 
 L<Rose::DB::Object> objects can represent rows in almost any database table, subject to the following constraints.
@@ -1616,6 +1622,10 @@ The L<Rose development policy|Rose/"DEVELOPMENT POLICY"> applies to this, and al
 
 =head1 SUPPORT
 
+For an informal overview of L<Rose::DB::Object>, consult the L<Rose::DB::Object::Tutorial>.
+
+    perldoc Rose::DB::Object::Tutorial
+
 Any L<Rose::DB::Object> questions or problems can be posted to the L<Rose::DB::Object> mailing list.  To subscribe to the list or view the archives, go here:
 
 L<http://lists.sourceforge.net/lists/listinfo/rose-db-object>
